import grpc
import jwt  # pip install pyJWT, ATTENTION, no pip install jwt!!
import time
import os
import logging
from datetime import datetime
from retry import retry

from . import auth_pb2
from . import auth_pb2_grpc

# CONSTANTS
BX_HEADER_TOKEN_NAME = "bx_token"
CHANNEL_TIMEOUT = 40  # In seconds
LOGGER = logging.getLogger('batchx');

# CONFIG
CALL_DELAY = 0.5      # Initial delay (in seconds) between remote method call attempts.
CALL_BACKOFF = 2      # Multiplier applied to delay between attempts.
CALL_MAX_DELAY = 60   # Maximum value of delay (in seconds).
MAX_TRIES = 10        # The maximum number of attempts. default: -1 (infinite).
CALL_TIMEOUT = 60     # Unary call timeout in seconds.

channel = None  # Connection managed at module level. One common channel for all service classes within the module.
bx_token = None
access_token = None
bx_endpoint = None


class RecoverableException(Exception):
    """Raised when a recoverable error occurs.
    It's used just to detect failed connections attempts and try again.
    So, do nothing.
    """
    pass


def is_recoverable(exception):
    if exception is None or exception.code() is None:
        return False
    if grpc.StatusCode.PERMISSION_DENIED == exception.code():
        return check()
    return grpc.StatusCode.NOT_FOUND != exception.code() and \
           grpc.StatusCode.ALREADY_EXISTS != exception.code() and \
           grpc.StatusCode.UNKNOWN != exception.code() and \
           grpc.StatusCode.INVALID_ARGUMENT != exception.code() and \
           grpc.StatusCode.FAILED_PRECONDITION != exception.code() and \
           grpc.StatusCode.UNAUTHENTICATED != exception.code()


def connect():
    connect_to(os.environ["BATCHX_ENDPOINT"], os.environ["BATCHX_TOKEN"], "BATCHX_SECURE_CONNECTION" not in os.environ.keys() or os.environ["BATCHX_SECURE_CONNECTION"]!="OFF");

@retry(RecoverableException, delay=CALL_DELAY, backoff=CALL_BACKOFF, max_delay=CALL_MAX_DELAY, tries=MAX_TRIES)
def connect_to(endpoint, token, secure):
    global channel, bx_token, bx_endpoint
    if channel is None:
        try:
            if secure:
                channel = grpc.secure_channel(endpoint, grpc.ssl_channel_credentials(), options={
                    "grpc.keepalive_time_ms": 30000,
                    'grpc.keepalive_timeout_ms': 30*60*1000,
                    'grpc.keepalive_permit_without_calls': True
                }.items())
            else:
                channel = grpc.insecure_channel(endpoint)
            grpc.channel_ready_future(channel).result(CHANNEL_TIMEOUT)
        except grpc.FutureTimeoutError as exc:
            channel = None
            raise RecoverableException
    bx_token = token
    bx_endpoint = endpoint


def channel_is_working():
    global channel
    if channel is not None:
        try:
            grpc.channel_ready_future(channel).result(CHANNEL_TIMEOUT)
            return True
        except grpc.FutureTimeoutError:
            pass
    return False


def current_access_token_is_valid():
    global access_token
    if access_token is None:
        return False
    else:
        access_token_dict = jwt.decode(access_token, options={"verify_signature":False})
        return access_token_dict['exp'] > time.time()

# Refreshes the current token. Returns False if it was already valid
def check():
    """Check whether there exist a working channel and a valid access token."""
    global bx_endpoint, bx_token
    if not channel_is_working() and bx_endpoint is not None and bx_token is not None:
        connect(bx_endpoint, bx_token)
    if not current_access_token_is_valid():
        login()
        return True
    return False


@retry(RecoverableException, delay=CALL_DELAY, backoff=CALL_BACKOFF, max_delay=CALL_MAX_DELAY, tries=MAX_TRIES)
def make_call(func, request, auth_required=True, include_timeout=True):
    """Wrapper to manage remote method calls. It implements a retry policy with exponential backoff.

    :param str func: Function in charge of calling remote methods.
    :param str request: grpc message.
    :param str auth_required: if set to True or not passed, token header will be sent.
    :param str include_timeout: if set to True or not passed, default GRPC deadline will be set.
    :return: response returned by executing the function passed as parameter (func).
    """
    try:
        if include_timeout:
            timeout = CALL_TIMEOUT
        else:
            timeout = None;
        if auth_required:
            return func(request, metadata=[(BX_HEADER_TOKEN_NAME, access_token)], timeout=timeout)
        else:
            return func(request, timeout=timeout)
    except grpc.RpcError as exc:
        if is_recoverable(exc):
            raise RecoverableException  # If error is recoverable, retry call
        else:
            raise exc


def login():
    """ Connect to server and obtain an access token if needed."""
    global channel, bx_token, access_token
    if bx_token is not None:
        token = jwt.decode(bx_token, options={"verify_signature":False});
        if token['batchx-token-type'] == 'refresh':
            request_data = auth_pb2.RefreshTokenRequest(user_name=token['batchx-id'], refresh_token=bx_token)
            response = make_call(auth_pb2_grpc.AuthServiceStub(channel).RefreshToken, request_data, auth_required=False)
            access_token = response.access_token
        else:
            access_token = bx_token
    else:
        raise Exception("Batchx token not set. Please run: bx.connect()")


from . import billing_pb2
from . import billing_pb2_grpc
class BillingService:

    def CreatePaymentIntent(self, request):
        check()
        return make_call(billing_pb2_grpc.BillingServiceStub(channel).CreatePaymentIntent, request)

    def CreatePaymentIntentRequest(self, **kwargs):
        return billing_pb2.CreatePaymentIntentRequest(**kwargs)

    def CreatePaymentIntentResponse(self, **kwargs):
        return billing_pb2.CreatePaymentIntentResponse(**kwargs)


from . import filesystem_pb2
from . import filesystem_pb2_grpc
class FilesystemService:

    def CancelUpload(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).CancelUpload, request)

    def CompleteUpload(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).CompleteUpload, request)

    def Copy(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).Copy, request)

    def DeleteFile(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).DeleteFile, request)

    def DownloadPresigned(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).DownloadPresigned, request)

    def GetBlob(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).GetBlob, request)

    def GetFile(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).GetFile, request)

    def ListBlobPointers(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ListBlobPointers, request)

    def ListBlobs(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ListBlobs, request)

    def ListFolder(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ListFolder, request)

    def ReportUploadStatus(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ReportUploadStatus, request)

    def SetBlobStatus(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).SetBlobStatus, request)

    def ShareFile(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ShareFile, request)

    def UploadPresigned(self, request):
        check()
        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).UploadPresigned, request)

    def Blob(self, **kwargs):
        return filesystem_pb2.Blob(**kwargs)

    def CancelUploadRequest(self, **kwargs):
        return filesystem_pb2.CancelUploadRequest(**kwargs)

    def CancelUploadResponse(self, **kwargs):
        return filesystem_pb2.CancelUploadResponse(**kwargs)

    def CompleteUploadRequest(self, **kwargs):
        return filesystem_pb2.CompleteUploadRequest(**kwargs)

    def CompleteUploadResponse(self, **kwargs):
        return filesystem_pb2.CompleteUploadResponse(**kwargs)

    def CopyRequest(self, **kwargs):
        return filesystem_pb2.CopyRequest(**kwargs)

    def CreateFolderRequest(self, **kwargs):
        return filesystem_pb2.CreateFolderRequest(**kwargs)

    def CreateFolderResponse(self, **kwargs):
        return filesystem_pb2.CreateFolderResponse(**kwargs)

    def DeleteFileRequest(self, **kwargs):
        return filesystem_pb2.DeleteFileRequest(**kwargs)

    def DeleteFileResponse(self, **kwargs):
        return filesystem_pb2.DeleteFileResponse(**kwargs)

    def DeleteFolderRequest(self, **kwargs):
        return filesystem_pb2.DeleteFolderRequest(**kwargs)

    def DeleteFolderResponse(self, **kwargs):
        return filesystem_pb2.DeleteFolderResponse(**kwargs)

    def DownloadPresignedRequest(self, **kwargs):
        return filesystem_pb2.DownloadPresignedRequest(**kwargs)

    def DownloadPresignedResponse(self, **kwargs):
        return filesystem_pb2.DownloadPresignedResponse(**kwargs)

    def File(self, **kwargs):
        return filesystem_pb2.File(**kwargs)

    def GetBlobRequest(self, **kwargs):
        return filesystem_pb2.GetBlobRequest(**kwargs)

    def GetBlobResponse(self, **kwargs):
        return filesystem_pb2.GetBlobResponse(**kwargs)

    def GetFileRequest(self, **kwargs):
        return filesystem_pb2.GetFileRequest(**kwargs)

    def GetFileResponse(self, **kwargs):
        return filesystem_pb2.GetFileResponse(**kwargs)

    def ListBlobPointersRequest(self, **kwargs):
        return filesystem_pb2.ListBlobPointersRequest(**kwargs)

    def ListBlobPointersResponse(self, **kwargs):
        return filesystem_pb2.ListBlobPointersResponse(**kwargs)

    def ListBlobsRequest(self, **kwargs):
        return filesystem_pb2.ListBlobsRequest(**kwargs)

    def ListBlobsResponse(self, **kwargs):
        return filesystem_pb2.ListBlobsResponse(**kwargs)

    def ListFolderRequest(self, **kwargs):
        return filesystem_pb2.ListFolderRequest(**kwargs)

    def ListFolderResponse(self, **kwargs):
        return filesystem_pb2.ListFolderResponse(**kwargs)

    def Metadata(self, **kwargs):
        return filesystem_pb2.Metadata(**kwargs)

    def ReportUploadStatusRequest(self, **kwargs):
        return filesystem_pb2.ReportUploadStatusRequest(**kwargs)

    def ReportUploadStatusResponse(self, **kwargs):
        return filesystem_pb2.ReportUploadStatusResponse(**kwargs)

    def SetBlobStatusRequest(self, **kwargs):
        return filesystem_pb2.SetBlobStatusRequest(**kwargs)

    def SetBlobStatusResponse(self, **kwargs):
        return filesystem_pb2.SetBlobStatusResponse(**kwargs)

    def ShareFileRequest(self, **kwargs):
        return filesystem_pb2.ShareFileRequest(**kwargs)

    def ShareFileResponse(self, **kwargs):
        return filesystem_pb2.ShareFileResponse(**kwargs)

    def UploadPresignedRequest(self, **kwargs):
        return filesystem_pb2.UploadPresignedRequest(**kwargs)

    def UploadPresignedResponse(self, **kwargs):
        return filesystem_pb2.UploadPresignedResponse(**kwargs)


from . import consumer_pb2
from . import consumer_pb2_grpc
class ConsumerService:

    def GetMetrics(self, request):
        check()
        return make_call(consumer_pb2_grpc.ConsumerServiceStub(channel).GetMetrics, request)

    def GetMetricsRequest(self, **kwargs):
        return consumer_pb2.GetMetricsRequest(**kwargs)

    def GetMetricsResponse(self, **kwargs):
        return consumer_pb2.GetMetricsResponse(**kwargs)


from . import picture_pb2
from . import picture_pb2_grpc
class PictureService:

    def CompleteUpload(self, request):
        check()
        return make_call(picture_pb2_grpc.PictureServiceStub(channel).CompleteUpload, request)

    def CropPicture(self, request):
        check()
        return make_call(picture_pb2_grpc.PictureServiceStub(channel).CropPicture, request)

    def Upload(self, request):
        check()
        return make_call(picture_pb2_grpc.PictureServiceStub(channel).Upload, request)

    def CompleteUploadRequest(self, **kwargs):
        return picture_pb2.CompleteUploadRequest(**kwargs)

    def CompleteUploadResponse(self, **kwargs):
        return picture_pb2.CompleteUploadResponse(**kwargs)

    def CropPictureRequest(self, **kwargs):
        return picture_pb2.CropPictureRequest(**kwargs)

    def CropPictureResponse(self, **kwargs):
        return picture_pb2.CropPictureResponse(**kwargs)

    def UploadRequest(self, **kwargs):
        return picture_pb2.UploadRequest(**kwargs)

    def UploadResponse(self, **kwargs):
        return picture_pb2.UploadResponse(**kwargs)


from . import token_pb2
from . import token_pb2_grpc
class TokenService:

    def AddToken(self, request):
        check()
        return make_call(token_pb2_grpc.TokenServiceStub(channel).AddToken, request)

    def AddTokenRequest(self, **kwargs):
        return token_pb2.AddTokenRequest(**kwargs)

    def AddTokenResponse(self, **kwargs):
        return token_pb2.AddTokenResponse(**kwargs)


from . import admin_pb2
from . import admin_pb2_grpc
class AdminService:

    def AddEnvironmentCredits(self, request):
        check()
        return make_call(admin_pb2_grpc.AdminServiceStub(channel).AddEnvironmentCredits, request)

    def CreateMembership(self, request):
        check()
        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateMembership, request)

    def CreateOrg(self, request):
        check()
        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateOrg, request)

    def CreateUser(self, request):
        check()
        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateUser, request)

    def GeneratePromoCode(self, request):
        check()
        return make_call(admin_pb2_grpc.AdminServiceStub(channel).GeneratePromoCode, request)

    def GetGlobalProperties(self, request):
        check()
        return make_call(admin_pb2_grpc.AdminServiceStub(channel).GetGlobalProperties, request)

    def RemoveUser(self, request):
        check()
        return make_call(admin_pb2_grpc.AdminServiceStub(channel).RemoveUser, request)

    def SetGlobalProperty(self, request):
        check()
        return make_call(admin_pb2_grpc.AdminServiceStub(channel).SetGlobalProperty, request)

    def AddEnvironmentCreditsRequest(self, **kwargs):
        return admin_pb2.AddEnvironmentCreditsRequest(**kwargs)

    def AddEnvironmentCreditsResponse(self, **kwargs):
        return admin_pb2.AddEnvironmentCreditsResponse(**kwargs)

    def Assignment(self, **kwargs):
        return admin_pb2.Assignment(**kwargs)

    def CreateMembershipRequest(self, **kwargs):
        return admin_pb2.CreateMembershipRequest(**kwargs)

    def CreateMembershipResponse(self, **kwargs):
        return admin_pb2.CreateMembershipResponse(**kwargs)

    def CreateOrgRequest(self, **kwargs):
        return admin_pb2.CreateOrgRequest(**kwargs)

    def CreateOrgResponse(self, **kwargs):
        return admin_pb2.CreateOrgResponse(**kwargs)

    def CreateUserRequest(self, **kwargs):
        return admin_pb2.CreateUserRequest(**kwargs)

    def CreateUserResponse(self, **kwargs):
        return admin_pb2.CreateUserResponse(**kwargs)

    def GeneratePromoCodeRequest(self, **kwargs):
        return admin_pb2.GeneratePromoCodeRequest(**kwargs)

    def GeneratePromoCodeResponse(self, **kwargs):
        return admin_pb2.GeneratePromoCodeResponse(**kwargs)

    def GetGlobalPropertiesRequest(self, **kwargs):
        return admin_pb2.GetGlobalPropertiesRequest(**kwargs)

    def GetGlobalPropertiesResponse(self, **kwargs):
        return admin_pb2.GetGlobalPropertiesResponse(**kwargs)

    def RemoveUserRequest(self, **kwargs):
        return admin_pb2.RemoveUserRequest(**kwargs)

    def RemoveUserResponse(self, **kwargs):
        return admin_pb2.RemoveUserResponse(**kwargs)

    def SetGlobalPropertyRequest(self, **kwargs):
        return admin_pb2.SetGlobalPropertyRequest(**kwargs)

    def SetGlobalPropertyResponse(self, **kwargs):
        return admin_pb2.SetGlobalPropertyResponse(**kwargs)


from . import audit_pb2
from . import audit_pb2_grpc
class AuditService:

    def ListEvents(self, request):
        check()
        return make_call(audit_pb2_grpc.AuditServiceStub(channel).ListEvents, request)

    def Event(self, **kwargs):
        return audit_pb2.Event(**kwargs)

    def ListEventsRequest(self, **kwargs):
        return audit_pb2.ListEventsRequest(**kwargs)

    def ListEventsResponse(self, **kwargs):
        return audit_pb2.ListEventsResponse(**kwargs)


from . import job_pb2
from . import job_pb2_grpc
class JobService:

    def Cancel(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).Cancel, request)

    def CloseWorkflow(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).CloseWorkflow, request)

    def CreateWorkflow(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).CreateWorkflow, request)

    def Delete(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).Delete, request)

    def DeleteWorkflow(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).DeleteWorkflow, request)

    def GetComputationalCost(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).GetComputationalCost, request)

    def GetJob(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).GetJob, request)

    def GetLogs(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).GetLogs, request)

    def GetWorkflow(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).GetWorkflow, request)

    def GetWorkflowGraph(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).GetWorkflowGraph, request)

    def ListJobs(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).ListJobs, request)

    def ListWorkflows(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).ListWorkflows, request)

    def Stream(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).Stream, request, include_timeout=False)

    def Submit(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).Submit, request)

    def TagJob(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).TagJob, request)

    def TagWorkflow(self, request):
        check()
        return make_call(job_pb2_grpc.JobServiceStub(channel).TagWorkflow, request)

    def Run(self, submit_request):
        submit_response = self.Submit(submit_request)
        if submit_response.WhichOneof("case") == "suggested_parameters":
            raise Exception("Unsupported job parametrization. Suggested one is: " + str(submit_response.suggested_parameters))
        request_stream = self.StreamRequest(environment=submit_request.environment, job_id=submit_response.job_id, logs_enabled=True)
        return self.__ProcessStream(submit_request, request_stream)

    @retry(RecoverableException, delay=CALL_DELAY, backoff=CALL_BACKOFF, max_delay=CALL_MAX_DELAY, tries=MAX_TRIES)
    def __ProcessStream(self, submit_request, request_stream):
        try:
            response = self.Stream(request_stream)
            for r in response:
                for job_event in r.event:
                    if job_event.WhichOneof("type") == "job_status":
                        LOGGER.warning("["+request_stream.environment+"#"+str(request_stream.job_id)+"] Job status: " + job_pb2.Status.Name(job_event.job_status))
                    elif job_event.WhichOneof("type") == "log_record":
                        LOGGER.warning("["+request_stream.environment+"#"+str(request_stream.job_id)+"|"+request_stream.environment+"@"+submit_request.image+"] ["+str(datetime.fromtimestamp(job_event.log_record.ts_millis/1000.0))+"] " +  job_event.log_record.message)
                    elif job_event.WhichOneof("type") == "return_value":
                        return job_event.return_value;
        except grpc.RpcError as exc:
            if is_recoverable(exc):
                raise RecoverableException  # If error is recoverable, retry call
            else:
                raise exc

    def CancelRequest(self, **kwargs):
        return job_pb2.CancelRequest(**kwargs)

    def CancelResponse(self, **kwargs):
        return job_pb2.CancelResponse(**kwargs)

    def CloseWorkflowRequest(self, **kwargs):
        return job_pb2.CloseWorkflowRequest(**kwargs)

    def CloseWorkflowResponse(self, **kwargs):
        return job_pb2.CloseWorkflowResponse(**kwargs)

    def CreateWorkflowRequest(self, **kwargs):
        return job_pb2.CreateWorkflowRequest(**kwargs)

    def CreateWorkflowResponse(self, **kwargs):
        return job_pb2.CreateWorkflowResponse(**kwargs)

    def DeleteRequest(self, **kwargs):
        return job_pb2.DeleteRequest(**kwargs)

    def DeleteResponse(self, **kwargs):
        return job_pb2.DeleteResponse(**kwargs)

    def DeleteWorkflowRequest(self, **kwargs):
        return job_pb2.DeleteWorkflowRequest(**kwargs)

    def DeleteWorkflowResponse(self, **kwargs):
        return job_pb2.DeleteWorkflowResponse(**kwargs)

    def GetComputationalCostRequest(self, **kwargs):
        return job_pb2.GetComputationalCostRequest(**kwargs)

    def GetComputationalCostResponse(self, **kwargs):
        return job_pb2.GetComputationalCostResponse(**kwargs)

    def GetJobRequest(self, **kwargs):
        return job_pb2.GetJobRequest(**kwargs)

    def GetJobResponse(self, **kwargs):
        return job_pb2.GetJobResponse(**kwargs)

    def GetLogsRequest(self, **kwargs):
        return job_pb2.GetLogsRequest(**kwargs)

    def GetWorkflowGraphRequest(self, **kwargs):
        return job_pb2.GetWorkflowGraphRequest(**kwargs)

    def GetWorkflowGraphResponse(self, **kwargs):
        return job_pb2.GetWorkflowGraphResponse(**kwargs)

    def GetWorkflowRequest(self, **kwargs):
        return job_pb2.GetWorkflowRequest(**kwargs)

    def GetWorkflowResponse(self, **kwargs):
        return job_pb2.GetWorkflowResponse(**kwargs)

    def Job(self, **kwargs):
        return job_pb2.Job(**kwargs)

    def JobEvent(self, **kwargs):
        return job_pb2.JobEvent(**kwargs)

    def JobStateMessage(self, **kwargs):
        return job_pb2.JobStateMessage(**kwargs)

    def ListJobsRequest(self, **kwargs):
        return job_pb2.ListJobsRequest(**kwargs)

    def ListJobsResponse(self, **kwargs):
        return job_pb2.ListJobsResponse(**kwargs)

    def ListWorkflowsRequest(self, **kwargs):
        return job_pb2.ListWorkflowsRequest(**kwargs)

    def ListWorkflowsResponse(self, **kwargs):
        return job_pb2.ListWorkflowsResponse(**kwargs)

    def StreamRequest(self, **kwargs):
        return job_pb2.StreamRequest(**kwargs)

    def StreamResponse(self, **kwargs):
        return job_pb2.StreamResponse(**kwargs)

    def SubmitRequest(self, **kwargs):
        return job_pb2.SubmitRequest(**kwargs)

    def SubmitResponse(self, **kwargs):
        return job_pb2.SubmitResponse(**kwargs)

    def TagJobRequest(self, **kwargs):
        return job_pb2.TagJobRequest(**kwargs)

    def TagJobResponse(self, **kwargs):
        return job_pb2.TagJobResponse(**kwargs)

    def TagWorkflowRequest(self, **kwargs):
        return job_pb2.TagWorkflowRequest(**kwargs)

    def TagWorkflowResponse(self, **kwargs):
        return job_pb2.TagWorkflowResponse(**kwargs)

    def Workflow(self, **kwargs):
        return job_pb2.Workflow(**kwargs)


from . import provider_pb2
from . import provider_pb2_grpc
class ProviderService:

    def GetMetrics(self, request):
        check()
        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).GetMetrics, request)

    def ListPayouts(self, request):
        check()
        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).ListPayouts, request)

    def ListRevenueByCustomer(self, request):
        check()
        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).ListRevenueByCustomer, request)

    def ListRevenueByTools(self, request):
        check()
        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).ListRevenueByTools, request)

    def GetMetricsRequest(self, **kwargs):
        return provider_pb2.GetMetricsRequest(**kwargs)

    def GetMetricsResponse(self, **kwargs):
        return provider_pb2.GetMetricsResponse(**kwargs)

    def ListPayoutsRequest(self, **kwargs):
        return provider_pb2.ListPayoutsRequest(**kwargs)

    def ListPayoutsResponse(self, **kwargs):
        return provider_pb2.ListPayoutsResponse(**kwargs)

    def ListRevenueByCustomerRequest(self, **kwargs):
        return provider_pb2.ListRevenueByCustomerRequest(**kwargs)

    def ListRevenueByCustomerResponse(self, **kwargs):
        return provider_pb2.ListRevenueByCustomerResponse(**kwargs)

    def ListRevenueByToolsRequest(self, **kwargs):
        return provider_pb2.ListRevenueByToolsRequest(**kwargs)

    def ListRevenueByToolsResponse(self, **kwargs):
        return provider_pb2.ListRevenueByToolsResponse(**kwargs)

    def Payout(self, **kwargs):
        return provider_pb2.Payout(**kwargs)


from . import user_pb2
from . import user_pb2_grpc
class UserService:

    def GetUser(self, request):
        check()
        return make_call(user_pb2_grpc.UserServiceStub(channel).GetUser, request)

    def UpdateUser(self, request):
        check()
        return make_call(user_pb2_grpc.UserServiceStub(channel).UpdateUser, request)

    def GetUserRequest(self, **kwargs):
        return user_pb2.GetUserRequest(**kwargs)

    def GetUserResponse(self, **kwargs):
        return user_pb2.GetUserResponse(**kwargs)

    def UpdateUserRequest(self, **kwargs):
        return user_pb2.UpdateUserRequest(**kwargs)

    def UpdateUserResponse(self, **kwargs):
        return user_pb2.UpdateUserResponse(**kwargs)


from . import auth_pb2
from . import auth_pb2_grpc
class AuthService:

    def ConfirmForgotPassword(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ConfirmForgotPassword, request)

    def ConfirmSignup(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ConfirmSignup, request)

    def ForgotPassword(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ForgotPassword, request)

    def GoogleSignin(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).GoogleSignin, request)

    def GoogleSignup(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).GoogleSignup, request)

    def Login(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).Login, request)

    def RefreshToken(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).RefreshToken, request)

    def ResendSignupConfirmationCode(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ResendSignupConfirmationCode, request)

    def RevokeRefreshToken(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).RevokeRefreshToken, request)

    def Signup(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).Signup, request)

    def StartSignup(self, request):
        check()
        return make_call(auth_pb2_grpc.AuthServiceStub(channel).StartSignup, request)

    def ConfirmForgotPasswordRequest(self, **kwargs):
        return auth_pb2.ConfirmForgotPasswordRequest(**kwargs)

    def ConfirmForgotPasswordResponse(self, **kwargs):
        return auth_pb2.ConfirmForgotPasswordResponse(**kwargs)

    def ConfirmSignupRequest(self, **kwargs):
        return auth_pb2.ConfirmSignupRequest(**kwargs)

    def ConfirmSignupResponse(self, **kwargs):
        return auth_pb2.ConfirmSignupResponse(**kwargs)

    def ForgotPasswordRequest(self, **kwargs):
        return auth_pb2.ForgotPasswordRequest(**kwargs)

    def ForgotPasswordResponse(self, **kwargs):
        return auth_pb2.ForgotPasswordResponse(**kwargs)

    def GoogleSigninRequest(self, **kwargs):
        return auth_pb2.GoogleSigninRequest(**kwargs)

    def GoogleSigninResponse(self, **kwargs):
        return auth_pb2.GoogleSigninResponse(**kwargs)

    def GoogleSignupRequest(self, **kwargs):
        return auth_pb2.GoogleSignupRequest(**kwargs)

    def GoogleSignupResponse(self, **kwargs):
        return auth_pb2.GoogleSignupResponse(**kwargs)

    def LoginRequest(self, **kwargs):
        return auth_pb2.LoginRequest(**kwargs)

    def LoginResponse(self, **kwargs):
        return auth_pb2.LoginResponse(**kwargs)

    def RefreshTokenRequest(self, **kwargs):
        return auth_pb2.RefreshTokenRequest(**kwargs)

    def RefreshTokenResponse(self, **kwargs):
        return auth_pb2.RefreshTokenResponse(**kwargs)

    def ResendSignupConfirmationCodeRequest(self, **kwargs):
        return auth_pb2.ResendSignupConfirmationCodeRequest(**kwargs)

    def ResendSignupConfirmationCodeResponse(self, **kwargs):
        return auth_pb2.ResendSignupConfirmationCodeResponse(**kwargs)

    def RevokeRefreshTokenRequest(self, **kwargs):
        return auth_pb2.RevokeRefreshTokenRequest(**kwargs)

    def RevokeRefreshTokenResponse(self, **kwargs):
        return auth_pb2.RevokeRefreshTokenResponse(**kwargs)

    def SignupRequest(self, **kwargs):
        return auth_pb2.SignupRequest(**kwargs)

    def SignupResponse(self, **kwargs):
        return auth_pb2.SignupResponse(**kwargs)

    def StartSignupRequest(self, **kwargs):
        return auth_pb2.StartSignupRequest(**kwargs)

    def StartSignupResponse(self, **kwargs):
        return auth_pb2.StartSignupResponse(**kwargs)

    def TokenResponse(self, **kwargs):
        return auth_pb2.TokenResponse(**kwargs)


from . import common_pb2
from . import common_pb2_grpc
class CommonService:

    def IntRangeFilter(self, **kwargs):
        return common_pb2.IntRangeFilter(**kwargs)

    def LongRangeFilter(self, **kwargs):
        return common_pb2.LongRangeFilter(**kwargs)

    def Organization(self, **kwargs):
        return common_pb2.Organization(**kwargs)

    def PageInfo(self, **kwargs):
        return common_pb2.PageInfo(**kwargs)

    def Picture(self, **kwargs):
        return common_pb2.Picture(**kwargs)

    def RateLimit(self, **kwargs):
        return common_pb2.RateLimit(**kwargs)

    def Region(self, **kwargs):
        return common_pb2.Region(**kwargs)

    def Thumbnail(self, **kwargs):
        return common_pb2.Thumbnail(**kwargs)

    def User(self, **kwargs):
        return common_pb2.User(**kwargs)


from . import docker_pb2
from . import docker_pb2_grpc
class DockerService:

    def DockerImageCoordinates(self, **kwargs):
        return docker_pb2.DockerImageCoordinates(**kwargs)


from . import health_pb2
from . import health_pb2_grpc
class HealthService:

    def HealthCheckRequest(self, **kwargs):
        return health_pb2.HealthCheckRequest(**kwargs)

    def HealthCheckResponse(self, **kwargs):
        return health_pb2.HealthCheckResponse(**kwargs)


from . import alert_pb2
from . import alert_pb2_grpc
class AlertService:

    def DismissAlert(self, request):
        check()
        return make_call(alert_pb2_grpc.AlertServiceStub(channel).DismissAlert, request)

    def DismissAllAlerts(self, request):
        check()
        return make_call(alert_pb2_grpc.AlertServiceStub(channel).DismissAllAlerts, request)

    def ListAlerts(self, request):
        check()
        return make_call(alert_pb2_grpc.AlertServiceStub(channel).ListAlerts, request)

    def Alert(self, **kwargs):
        return alert_pb2.Alert(**kwargs)

    def DismissAlertRequest(self, **kwargs):
        return alert_pb2.DismissAlertRequest(**kwargs)

    def DismissAlertResponse(self, **kwargs):
        return alert_pb2.DismissAlertResponse(**kwargs)

    def DismissAllAlertsRequest(self, **kwargs):
        return alert_pb2.DismissAllAlertsRequest(**kwargs)

    def DismissAllAlertsResponse(self, **kwargs):
        return alert_pb2.DismissAllAlertsResponse(**kwargs)

    def ListAlertsRequest(self, **kwargs):
        return alert_pb2.ListAlertsRequest(**kwargs)

    def ListAlertsResponse(self, **kwargs):
        return alert_pb2.ListAlertsResponse(**kwargs)


from . import profile_pb2
from . import profile_pb2_grpc
class ProfileService:

    def Profile(self, **kwargs):
        return profile_pb2.Profile(**kwargs)


from . import tag_pb2
from . import tag_pb2_grpc
class TagService:

    def CreateTag(self, request):
        check()
        return make_call(tag_pb2_grpc.TagServiceStub(channel).CreateTag, request)

    def DeleteTag(self, request):
        check()
        return make_call(tag_pb2_grpc.TagServiceStub(channel).DeleteTag, request)

    def DisableTag(self, request):
        check()
        return make_call(tag_pb2_grpc.TagServiceStub(channel).DisableTag, request)

    def GetTag(self, request):
        check()
        return make_call(tag_pb2_grpc.TagServiceStub(channel).GetTag, request)

    def ListEnvironmentTags(self, request):
        check()
        return make_call(tag_pb2_grpc.TagServiceStub(channel).ListEnvironmentTags, request)

    def UpdateTag(self, request):
        check()
        return make_call(tag_pb2_grpc.TagServiceStub(channel).UpdateTag, request)

    def CreateTagRequest(self, **kwargs):
        return tag_pb2.CreateTagRequest(**kwargs)

    def CreateTagResponse(self, **kwargs):
        return tag_pb2.CreateTagResponse(**kwargs)

    def DeleteTagRequest(self, **kwargs):
        return tag_pb2.DeleteTagRequest(**kwargs)

    def DeleteTagResponse(self, **kwargs):
        return tag_pb2.DeleteTagResponse(**kwargs)

    def DisableTagRequest(self, **kwargs):
        return tag_pb2.DisableTagRequest(**kwargs)

    def DisableTagResponse(self, **kwargs):
        return tag_pb2.DisableTagResponse(**kwargs)

    def GetTagRequest(self, **kwargs):
        return tag_pb2.GetTagRequest(**kwargs)

    def GetTagResponse(self, **kwargs):
        return tag_pb2.GetTagResponse(**kwargs)

    def ListEnvironmentTagsRequest(self, **kwargs):
        return tag_pb2.ListEnvironmentTagsRequest(**kwargs)

    def ListEnvironmentTagsResponse(self, **kwargs):
        return tag_pb2.ListEnvironmentTagsResponse(**kwargs)

    def Tag(self, **kwargs):
        return tag_pb2.Tag(**kwargs)

    def TagCoordinates(self, **kwargs):
        return tag_pb2.TagCoordinates(**kwargs)

    def TagData(self, **kwargs):
        return tag_pb2.TagData(**kwargs)

    def UpdateTagRequest(self, **kwargs):
        return tag_pb2.UpdateTagRequest(**kwargs)

    def UpdateTagResponse(self, **kwargs):
        return tag_pb2.UpdateTagResponse(**kwargs)


from . import organization_pb2
from . import organization_pb2_grpc
class OrganizationService:

    def CreateOrganization(self, request):
        check()
        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).CreateOrganization, request)

    def DeleteInvitation(self, request):
        check()
        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).DeleteInvitation, request)

    def DeleteMembership(self, request):
        check()
        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).DeleteMembership, request)

    def GetOrganization(self, request):
        check()
        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).GetOrganization, request)

    def HandleInvitation(self, request):
        check()
        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).HandleInvitation, request)

    def InviteMember(self, request):
        check()
        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).InviteMember, request)

    def ListOrganizationInvitations(self, request):
        check()
        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).ListOrganizationInvitations, request)

    def ListUserInvitations(self, request):
        check()
        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).ListUserInvitations, request)

    def UpdateOrganization(self, request):
        check()
        return make_call(organization_pb2_grpc.OrganizationServiceStub(channel).UpdateOrganization, request)

    def CreateOrganizationRequest(self, **kwargs):
        return organization_pb2.CreateOrganizationRequest(**kwargs)

    def CreateOrganizationResponse(self, **kwargs):
        return organization_pb2.CreateOrganizationResponse(**kwargs)

    def DeleteInvitationRequest(self, **kwargs):
        return organization_pb2.DeleteInvitationRequest(**kwargs)

    def DeleteInvitationResponse(self, **kwargs):
        return organization_pb2.DeleteInvitationResponse(**kwargs)

    def DeleteMembershipRequest(self, **kwargs):
        return organization_pb2.DeleteMembershipRequest(**kwargs)

    def DeleteMembershipResponse(self, **kwargs):
        return organization_pb2.DeleteMembershipResponse(**kwargs)

    def GetOrganizationRequest(self, **kwargs):
        return organization_pb2.GetOrganizationRequest(**kwargs)

    def GetOrganizationResponse(self, **kwargs):
        return organization_pb2.GetOrganizationResponse(**kwargs)

    def HandleInvitationRequest(self, **kwargs):
        return organization_pb2.HandleInvitationRequest(**kwargs)

    def HandleInvitationResponse(self, **kwargs):
        return organization_pb2.HandleInvitationResponse(**kwargs)

    def Invitation(self, **kwargs):
        return organization_pb2.Invitation(**kwargs)

    def InviteMemberRequest(self, **kwargs):
        return organization_pb2.InviteMemberRequest(**kwargs)

    def InviteMemberResponse(self, **kwargs):
        return organization_pb2.InviteMemberResponse(**kwargs)

    def ListOrganizationInvitationsRequest(self, **kwargs):
        return organization_pb2.ListOrganizationInvitationsRequest(**kwargs)

    def ListOrganizationInvitationsResponse(self, **kwargs):
        return organization_pb2.ListOrganizationInvitationsResponse(**kwargs)

    def ListUserInvitationsRequest(self, **kwargs):
        return organization_pb2.ListUserInvitationsRequest(**kwargs)

    def ListUserInvitationsResponse(self, **kwargs):
        return organization_pb2.ListUserInvitationsResponse(**kwargs)

    def UpdateOrganizationRequest(self, **kwargs):
        return organization_pb2.UpdateOrganizationRequest(**kwargs)

    def UpdateOrganizationResponse(self, **kwargs):
        return organization_pb2.UpdateOrganizationResponse(**kwargs)


from . import environment_pb2
from . import environment_pb2_grpc
class EnvironmentService:

    def GetEnvironment(self, request):
        check()
        return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).GetEnvironment, request)

    def IsIdAvailable(self, request):
        check()
        return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).IsIdAvailable, request)

    def ListRegions(self, request):
        check()
        return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).ListRegions, request)

    def GetEnvironmentRequest(self, **kwargs):
        return environment_pb2.GetEnvironmentRequest(**kwargs)

    def GetEnvironmentResponse(self, **kwargs):
        return environment_pb2.GetEnvironmentResponse(**kwargs)

    def IsIdAvailableRequest(self, **kwargs):
        return environment_pb2.IsIdAvailableRequest(**kwargs)

    def IsIdAvailableResponse(self, **kwargs):
        return environment_pb2.IsIdAvailableResponse(**kwargs)

    def ListRegionsRequest(self, **kwargs):
        return environment_pb2.ListRegionsRequest(**kwargs)

    def ListRegionsResponse(self, **kwargs):
        return environment_pb2.ListRegionsResponse(**kwargs)

    def Region(self, **kwargs):
        return environment_pb2.Region(**kwargs)


from . import image_pb2
from . import image_pb2_grpc
class ImageService:

    def AreImageExamplesCloned(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).AreImageExamplesCloned, request)

    def CloneImage(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).CloneImage, request)

    def CloneImageExamples(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).CloneImageExamples, request)

    def DeleteImage(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).DeleteImage, request)

    def GetImage(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).GetImage, request)

    def GetPushCredentials(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).GetPushCredentials, request)

    def ImportImage(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).ImportImage, request)

    def ListImageExamples(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).ListImageExamples, request)

    def ListImages(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).ListImages, request)

    def RemoveImageExample(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).RemoveImageExample, request)

    def SearchImages(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).SearchImages, request)

    def SetImageExample(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).SetImageExample, request)

    def ShareImage(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).ShareImage, request)

    def TagImage(self, request):
        check()
        return make_call(image_pb2_grpc.ImageServiceStub(channel).TagImage, request)

    def AreImageExamplesClonedRequest(self, **kwargs):
        return image_pb2.AreImageExamplesClonedRequest(**kwargs)

    def AreImageExamplesClonedResponse(self, **kwargs):
        return image_pb2.AreImageExamplesClonedResponse(**kwargs)

    def CloneImageExamplesRequest(self, **kwargs):
        return image_pb2.CloneImageExamplesRequest(**kwargs)

    def CloneImageExamplesResponse(self, **kwargs):
        return image_pb2.CloneImageExamplesResponse(**kwargs)

    def CloneImageRequest(self, **kwargs):
        return image_pb2.CloneImageRequest(**kwargs)

    def CloneImageResponse(self, **kwargs):
        return image_pb2.CloneImageResponse(**kwargs)

    def DeleteImageRequest(self, **kwargs):
        return image_pb2.DeleteImageRequest(**kwargs)

    def GetImageRequest(self, **kwargs):
        return image_pb2.GetImageRequest(**kwargs)

    def GetImageResponse(self, **kwargs):
        return image_pb2.GetImageResponse(**kwargs)

    def GetPushCredentialsRequest(self, **kwargs):
        return image_pb2.GetPushCredentialsRequest(**kwargs)

    def GetPushCredentialsResponse(self, **kwargs):
        return image_pb2.GetPushCredentialsResponse(**kwargs)

    def Image(self, **kwargs):
        return image_pb2.Image(**kwargs)

    def ImportImageRequest(self, **kwargs):
        return image_pb2.ImportImageRequest(**kwargs)

    def ListImageExamplesRequest(self, **kwargs):
        return image_pb2.ListImageExamplesRequest(**kwargs)

    def ListImageExamplesResponse(self, **kwargs):
        return image_pb2.ListImageExamplesResponse(**kwargs)

    def ListImagesRequest(self, **kwargs):
        return image_pb2.ListImagesRequest(**kwargs)

    def ListImagesResponse(self, **kwargs):
        return image_pb2.ListImagesResponse(**kwargs)

    def RemoveImageExampleRequest(self, **kwargs):
        return image_pb2.RemoveImageExampleRequest(**kwargs)

    def RemoveImageExampleResponse(self, **kwargs):
        return image_pb2.RemoveImageExampleResponse(**kwargs)

    def SearchImagesRequest(self, **kwargs):
        return image_pb2.SearchImagesRequest(**kwargs)

    def SearchImagesResponse(self, **kwargs):
        return image_pb2.SearchImagesResponse(**kwargs)

    def SetImageExampleRequest(self, **kwargs):
        return image_pb2.SetImageExampleRequest(**kwargs)

    def SetImageExampleResponse(self, **kwargs):
        return image_pb2.SetImageExampleResponse(**kwargs)

    def ShareImageRequest(self, **kwargs):
        return image_pb2.ShareImageRequest(**kwargs)

    def ShareImageResponse(self, **kwargs):
        return image_pb2.ShareImageResponse(**kwargs)

    def TagImageRequest(self, **kwargs):
        return image_pb2.TagImageRequest(**kwargs)

    def TagImageResponse(self, **kwargs):
        return image_pb2.TagImageResponse(**kwargs)


from . import log_pb2
from . import log_pb2_grpc
class LogService:

    def LogRecord(self, **kwargs):
        return log_pb2.LogRecord(**kwargs)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: picture.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rpicture.proto\x12\nbatchx.cdn\x1a\x0c\x63ommon.proto\"\xdc\x01\n\x12\x43ropPictureRequest\x12\x13\n\x0bpicture_key\x18\x01 \x01(\t\x12-\n\x0cpicture_type\x18\x02 \x01(\x0e\x32\x17.batchx.cdn.PictureType\x12\x31\n\x04\x63rop\x18\x03 \x01(\x0b\x32#.batchx.cdn.CropPictureRequest.Crop\x1aO\n\x04\x43rop\x12%\n\x06region\x18\x01 \x01(\x0b\x32\x15.batchx.common.Region\x12 \n\x18keep_uncropped_thumbnail\x18\x02 \x01(\x08\">\n\x13\x43ropPictureResponse\x12\'\n\x07picture\x18\x01 \x01(\x0b\x32\x16.batchx.common.Picture\"9\n\rUploadRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x13\n\x0b\x66ile_length\x18\x02 \x01(\x03\"\x84\x02\n\x0eUploadResponse\x12\x43\n\x10upload_post_data\x18\x01 \x01(\x0b\x32).batchx.cdn.UploadResponse.UploadPostData\x1a\xac\x01\n\x0eUploadPostData\x12\x10\n\x08post_url\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12J\n\tpost_data\x18\x03 \x03(\x0b\x32\x37.batchx.cdn.UploadResponse.UploadPostData.PostDataEntry\x1a/\n\rPostDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf6\x01\n\x15\x43ompleteUploadRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x12\n\nupload_key\x18\x02 \x01(\t\x12-\n\x0cpicture_type\x18\x03 \x01(\x0e\x32\x17.batchx.cdn.PictureType\x12\x34\n\x04\x63rop\x18\x04 \x01(\x0b\x32&.batchx.cdn.CompleteUploadRequest.Crop\x1aO\n\x04\x43rop\x12%\n\x06region\x18\x01 \x01(\x0b\x32\x15.batchx.common.Region\x12 \n\x18keep_uncropped_thumbnail\x18\x02 \x01(\x08\"A\n\x16\x43ompleteUploadResponse\x12\'\n\x07picture\x18\x01 \x01(\x0b\x32\x16.batchx.common.Picture*@\n\x0bPictureType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\n\n\x06\x41VATAR\x10\x02\x12\r\n\tTHUMBNAIL\x10\x03\x32\x97\x02\n\x0ePictureService\x12\x44\n\x06Upload\x12\x19.batchx.cdn.UploadRequest\x1a\x1a.batchx.cdn.UploadResponse\"\x03\x90\x02\x01\x12\\\n\x0e\x43ompleteUpload\x12!.batchx.cdn.CompleteUploadRequest\x1a\".batchx.cdn.CompleteUploadResponse\"\x03\x90\x02\x02\x12S\n\x0b\x43ropPicture\x12\x1e.batchx.cdn.CropPictureRequest\x1a\x1f.batchx.cdn.CropPictureResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x02\x42\x1f\n\x0fio.batchx.protoB\x0cPictureProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'picture_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\014PictureProto'
  _UPLOADRESPONSE_UPLOADPOSTDATA_POSTDATAENTRY._options = None
  _UPLOADRESPONSE_UPLOADPOSTDATA_POSTDATAENTRY._serialized_options = b'8\001'
  _PICTURESERVICE._options = None
  _PICTURESERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\002'
  _PICTURESERVICE.methods_by_name['Upload']._options = None
  _PICTURESERVICE.methods_by_name['Upload']._serialized_options = b'\220\002\001'
  _PICTURESERVICE.methods_by_name['CompleteUpload']._options = None
  _PICTURESERVICE.methods_by_name['CompleteUpload']._serialized_options = b'\220\002\002'
  _PICTURESERVICE.methods_by_name['CropPicture']._options = None
  _PICTURESERVICE.methods_by_name['CropPicture']._serialized_options = b'\220\002\002'
  _PICTURETYPE._serialized_start=968
  _PICTURETYPE._serialized_end=1032
  _CROPPICTUREREQUEST._serialized_start=44
  _CROPPICTUREREQUEST._serialized_end=264
  _CROPPICTUREREQUEST_CROP._serialized_start=185
  _CROPPICTUREREQUEST_CROP._serialized_end=264
  _CROPPICTURERESPONSE._serialized_start=266
  _CROPPICTURERESPONSE._serialized_end=328
  _UPLOADREQUEST._serialized_start=330
  _UPLOADREQUEST._serialized_end=387
  _UPLOADRESPONSE._serialized_start=390
  _UPLOADRESPONSE._serialized_end=650
  _UPLOADRESPONSE_UPLOADPOSTDATA._serialized_start=478
  _UPLOADRESPONSE_UPLOADPOSTDATA._serialized_end=650
  _UPLOADRESPONSE_UPLOADPOSTDATA_POSTDATAENTRY._serialized_start=603
  _UPLOADRESPONSE_UPLOADPOSTDATA_POSTDATAENTRY._serialized_end=650
  _COMPLETEUPLOADREQUEST._serialized_start=653
  _COMPLETEUPLOADREQUEST._serialized_end=899
  _COMPLETEUPLOADREQUEST_CROP._serialized_start=185
  _COMPLETEUPLOADREQUEST_CROP._serialized_end=264
  _COMPLETEUPLOADRESPONSE._serialized_start=901
  _COMPLETEUPLOADRESPONSE._serialized_end=966
  _PICTURESERVICE._serialized_start=1035
  _PICTURESERVICE._serialized_end=1314
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import auth_pb2 as auth__pb2


class AuthServiceStub(object):
    """RPCs in this service do not use any implicit header
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Login = channel.unary_unary(
                '/batchx.auth.AuthService/Login',
                request_serializer=auth__pb2.LoginRequest.SerializeToString,
                response_deserializer=auth__pb2.LoginResponse.FromString,
                )
        self.ForgotPassword = channel.unary_unary(
                '/batchx.auth.AuthService/ForgotPassword',
                request_serializer=auth__pb2.ForgotPasswordRequest.SerializeToString,
                response_deserializer=auth__pb2.ForgotPasswordResponse.FromString,
                )
        self.ConfirmForgotPassword = channel.unary_unary(
                '/batchx.auth.AuthService/ConfirmForgotPassword',
                request_serializer=auth__pb2.ConfirmForgotPasswordRequest.SerializeToString,
                response_deserializer=auth__pb2.ConfirmForgotPasswordResponse.FromString,
                )
        self.RefreshToken = channel.unary_unary(
                '/batchx.auth.AuthService/RefreshToken',
                request_serializer=auth__pb2.RefreshTokenRequest.SerializeToString,
                response_deserializer=auth__pb2.RefreshTokenResponse.FromString,
                )
        self.RevokeRefreshToken = channel.unary_unary(
                '/batchx.auth.AuthService/RevokeRefreshToken',
                request_serializer=auth__pb2.RevokeRefreshTokenRequest.SerializeToString,
                response_deserializer=auth__pb2.RevokeRefreshTokenResponse.FromString,
                )
        self.Signup = channel.unary_unary(
                '/batchx.auth.AuthService/Signup',
                request_serializer=auth__pb2.SignupRequest.SerializeToString,
                response_deserializer=auth__pb2.SignupResponse.FromString,
                )
        self.ConfirmSignup = channel.unary_unary(
                '/batchx.auth.AuthService/ConfirmSignup',
                request_serializer=auth__pb2.ConfirmSignupRequest.SerializeToString,
                response_deserializer=auth__pb2.ConfirmSignupResponse.FromString,
                )
        self.GoogleSignin = channel.unary_unary(
                '/batchx.auth.AuthService/GoogleSignin',
                request_serializer=auth__pb2.GoogleSigninRequest.SerializeToString,
                response_deserializer=auth__pb2.GoogleSigninResponse.FromString,
                )
        self.GoogleSignup = channel.unary_unary(
                '/batchx.auth.AuthService/GoogleSignup',
                request_serializer=auth__pb2.GoogleSignupRequest.SerializeToString,
                response_deserializer=auth__pb2.GoogleSignupResponse.FromString,
                )
        self.ResendSignupConfirmationCode = channel.unary_unary(
                '/batchx.auth.AuthService/ResendSignupConfirmationCode',
                request_serializer=auth__pb2.ResendSignupConfirmationCodeRequest.SerializeToString,
                response_deserializer=auth__pb2.ResendSignupConfirmationCodeResponse.FromString,
                )
        self.StartSignup = channel.unary_unary(
                '/batchx.auth.AuthService/StartSignup',
                request_serializer=auth__pb2.StartSignupRequest.SerializeToString,
                response_deserializer=auth__pb2.StartSignupResponse.FromString,
                )


class AuthServiceServicer(object):
    """RPCs in this service do not use any implicit header
    """

    def Login(self, request, context):
        """Authenticates a user. A user authenticates by answering successive challenges until authentication either fails or the user is issued tokens
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ForgotPassword(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmForgotPassword(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeRefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Signup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmSignup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GoogleSignin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GoogleSignup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResendSignupConfirmationCode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartSignup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=auth__pb2.LoginRequest.FromString,
                    response_serializer=auth__pb2.LoginResponse.SerializeToString,
            ),
            'ForgotPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ForgotPassword,
                    request_deserializer=auth__pb2.ForgotPasswordRequest.FromString,
                    response_serializer=auth__pb2.ForgotPasswordResponse.SerializeToString,
            ),
            'ConfirmForgotPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmForgotPassword,
                    request_deserializer=auth__pb2.ConfirmForgotPasswordRequest.FromString,
                    response_serializer=auth__pb2.ConfirmForgotPasswordResponse.SerializeToString,
            ),
            'RefreshToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshToken,
                    request_deserializer=auth__pb2.RefreshTokenRequest.FromString,
                    response_serializer=auth__pb2.RefreshTokenResponse.SerializeToString,
            ),
            'RevokeRefreshToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeRefreshToken,
                    request_deserializer=auth__pb2.RevokeRefreshTokenRequest.FromString,
                    response_serializer=auth__pb2.RevokeRefreshTokenResponse.SerializeToString,
            ),
            'Signup': grpc.unary_unary_rpc_method_handler(
                    servicer.Signup,
                    request_deserializer=auth__pb2.SignupRequest.FromString,
                    response_serializer=auth__pb2.SignupResponse.SerializeToString,
            ),
            'ConfirmSignup': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmSignup,
                    request_deserializer=auth__pb2.ConfirmSignupRequest.FromString,
                    response_serializer=auth__pb2.ConfirmSignupResponse.SerializeToString,
            ),
            'GoogleSignin': grpc.unary_unary_rpc_method_handler(
                    servicer.GoogleSignin,
                    request_deserializer=auth__pb2.GoogleSigninRequest.FromString,
                    response_serializer=auth__pb2.GoogleSigninResponse.SerializeToString,
            ),
            'GoogleSignup': grpc.unary_unary_rpc_method_handler(
                    servicer.GoogleSignup,
                    request_deserializer=auth__pb2.GoogleSignupRequest.FromString,
                    response_serializer=auth__pb2.GoogleSignupResponse.SerializeToString,
            ),
            'ResendSignupConfirmationCode': grpc.unary_unary_rpc_method_handler(
                    servicer.ResendSignupConfirmationCode,
                    request_deserializer=auth__pb2.ResendSignupConfirmationCodeRequest.FromString,
                    response_serializer=auth__pb2.ResendSignupConfirmationCodeResponse.SerializeToString,
            ),
            'StartSignup': grpc.unary_unary_rpc_method_handler(
                    servicer.StartSignup,
                    request_deserializer=auth__pb2.StartSignupRequest.FromString,
                    response_serializer=auth__pb2.StartSignupResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.auth.AuthService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuthService(object):
    """RPCs in this service do not use any implicit header
    """

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/Login',
            auth__pb2.LoginRequest.SerializeToString,
            auth__pb2.LoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ForgotPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/ForgotPassword',
            auth__pb2.ForgotPasswordRequest.SerializeToString,
            auth__pb2.ForgotPasswordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfirmForgotPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/ConfirmForgotPassword',
            auth__pb2.ConfirmForgotPasswordRequest.SerializeToString,
            auth__pb2.ConfirmForgotPasswordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RefreshToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/RefreshToken',
            auth__pb2.RefreshTokenRequest.SerializeToString,
            auth__pb2.RefreshTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeRefreshToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/RevokeRefreshToken',
            auth__pb2.RevokeRefreshTokenRequest.SerializeToString,
            auth__pb2.RevokeRefreshTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Signup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/Signup',
            auth__pb2.SignupRequest.SerializeToString,
            auth__pb2.SignupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfirmSignup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/ConfirmSignup',
            auth__pb2.ConfirmSignupRequest.SerializeToString,
            auth__pb2.ConfirmSignupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GoogleSignin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/GoogleSignin',
            auth__pb2.GoogleSigninRequest.SerializeToString,
            auth__pb2.GoogleSigninResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GoogleSignup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/GoogleSignup',
            auth__pb2.GoogleSignupRequest.SerializeToString,
            auth__pb2.GoogleSignupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResendSignupConfirmationCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/ResendSignupConfirmationCode',
            auth__pb2.ResendSignupConfirmationCodeRequest.SerializeToString,
            auth__pb2.ResendSignupConfirmationCodeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartSignup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.auth.AuthService/StartSignup',
            auth__pb2.StartSignupRequest.SerializeToString,
            auth__pb2.StartSignupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: alert.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61lert.proto\x12\x0c\x62\x61tchx.alert\x1a\x0c\x63ommon.proto\"\"\n\x13\x44ismissAlertRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x16\n\x14\x44ismissAlertResponse\"\x19\n\x17\x44ismissAllAlertsRequest\"\x1a\n\x18\x44ismissAllAlertsResponse\"\xe1\x07\n\x05\x41lert\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x13\n\x0bts_creation\x18\x02 \x01(\x03\x12&\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x18.batchx.alert.Alert.Data\x1a\x8d\x07\n\x04\x44\x61ta\x12:\n\x0blow_credits\x18\x01 \x01(\x0b\x32#.batchx.alert.Alert.Data.LowCreditsH\x00\x12R\n\x17organization_invitation\x18\x02 \x01(\x0b\x32/.batchx.alert.Alert.Data.OrganizationInvitationH\x00\x12\x39\n\x0bno_jobs_run\x18\x03 \x01(\x0b\x32\".batchx.alert.Alert.Data.NoJobsRunH\x00\x12\x45\n\x11no_files_uploaded\x18\x04 \x01(\x0b\x32(.batchx.alert.Alert.Data.NoFilesUploadedH\x00\x12Q\n\x17no_organization_created\x18\x05 \x01(\x0b\x32..batchx.alert.Alert.Data.NoOrganizationCreatedH\x00\x12<\n\x0cimage_shared\x18\x06 \x01(\x0b\x32$.batchx.alert.Alert.Data.ImageSharedH\x00\x12\x45\n\x11welcome_to_batchx\x18\x07 \x01(\x0b\x32(.batchx.alert.Alert.Data.WelcomeToBatchXH\x00\x1a!\n\nLowCredits\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x1a\x7f\n\x16OrganizationInvitation\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\n\n\x02\x62y\x18\x02 \x01(\t\x12\x43\n\x04type\x18\x03 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipType\x1a\x19\n\tNoJobsRun\x12\x0c\n\x04user\x18\x01 \x01(\t\x1a\x1f\n\x0fNoFilesUploaded\x12\x0c\n\x04user\x18\x01 \x01(\t\x1a%\n\x15NoOrganizationCreated\x12\x0c\n\x04user\x18\x01 \x01(\t\x1ak\n\x0bImageShared\x12\x19\n\x11image_environment\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\x12\x11\n\tshared_by\x18\x03 \x01(\t\x12\x1a\n\x12target_environment\x18\x04 \x01(\t\x1a\x1f\n\x0fWelcomeToBatchX\x12\x0c\n\x04user\x18\x01 \x01(\tB\x06\n\x04\x43\x61se\"\'\n\x11ListAlertsRequest\x12\x12\n\nreturn_all\x18\x01 \x01(\x08\"8\n\x12ListAlertsResponse\x12\"\n\x05\x61lert\x18\x01 \x03(\x0b\x32\x13.batchx.alert.Alert2\xb6\x02\n\x0c\x41lertService\x12Z\n\x0c\x44ismissAlert\x12!.batchx.alert.DismissAlertRequest\x1a\".batchx.alert.DismissAlertResponse\"\x03\x90\x02\x02\x12\x66\n\x10\x44ismissAllAlerts\x12%.batchx.alert.DismissAllAlertsRequest\x1a&.batchx.alert.DismissAllAlertsResponse\"\x03\x90\x02\x02\x12T\n\nListAlerts\x12\x1f.batchx.alert.ListAlertsRequest\x1a .batchx.alert.ListAlertsResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\x05\x82\x97\"\x02\x10\x01\x42\x1d\n\x0fio.batchx.protoB\nAlertProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'alert_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\nAlertProto'
  _ALERTSERVICE._options = None
  _ALERTSERVICE._serialized_options = b'\202\227\"\002\010\005\202\227\"\002\020\001'
  _ALERTSERVICE.methods_by_name['DismissAlert']._options = None
  _ALERTSERVICE.methods_by_name['DismissAlert']._serialized_options = b'\220\002\002'
  _ALERTSERVICE.methods_by_name['DismissAllAlerts']._options = None
  _ALERTSERVICE.methods_by_name['DismissAllAlerts']._serialized_options = b'\220\002\002'
  _ALERTSERVICE.methods_by_name['ListAlerts']._options = None
  _ALERTSERVICE.methods_by_name['ListAlerts']._serialized_options = b'\220\002\002'
  _DISMISSALERTREQUEST._serialized_start=43
  _DISMISSALERTREQUEST._serialized_end=77
  _DISMISSALERTRESPONSE._serialized_start=79
  _DISMISSALERTRESPONSE._serialized_end=101
  _DISMISSALLALERTSREQUEST._serialized_start=103
  _DISMISSALLALERTSREQUEST._serialized_end=128
  _DISMISSALLALERTSRESPONSE._serialized_start=130
  _DISMISSALLALERTSRESPONSE._serialized_end=156
  _ALERT._serialized_start=159
  _ALERT._serialized_end=1152
  _ALERT_DATA._serialized_start=243
  _ALERT_DATA._serialized_end=1152
  _ALERT_DATA_LOWCREDITS._serialized_start=741
  _ALERT_DATA_LOWCREDITS._serialized_end=774
  _ALERT_DATA_ORGANIZATIONINVITATION._serialized_start=776
  _ALERT_DATA_ORGANIZATIONINVITATION._serialized_end=903
  _ALERT_DATA_NOJOBSRUN._serialized_start=905
  _ALERT_DATA_NOJOBSRUN._serialized_end=930
  _ALERT_DATA_NOFILESUPLOADED._serialized_start=932
  _ALERT_DATA_NOFILESUPLOADED._serialized_end=963
  _ALERT_DATA_NOORGANIZATIONCREATED._serialized_start=965
  _ALERT_DATA_NOORGANIZATIONCREATED._serialized_end=1002
  _ALERT_DATA_IMAGESHARED._serialized_start=1004
  _ALERT_DATA_IMAGESHARED._serialized_end=1111
  _ALERT_DATA_WELCOMETOBATCHX._serialized_start=1113
  _ALERT_DATA_WELCOMETOBATCHX._serialized_end=1144
  _LISTALERTSREQUEST._serialized_start=1154
  _LISTALERTSREQUEST._serialized_end=1193
  _LISTALERTSRESPONSE._serialized_start=1195
  _LISTALERTSRESPONSE._serialized_end=1251
  _ALERTSERVICE._serialized_start=1254
  _ALERTSERVICE._serialized_end=1564
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61\x64min.proto\x12\x0c\x62\x61tchx.admin\x1a\x0c\x63ommon.proto\"\xc4\x01\n\x18GeneratePromoCodeRequest\x12?\n\x07\x63redits\x18\x01 \x01(\x0e\x32..batchx.admin.GeneratePromoCodeRequest.Credits\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x16\n\x0eusages_allowed\x18\x03 \x01(\x05\x12\x13\n\x0b\x64istributor\x18\x04 \x01(\t\"%\n\x07\x43redits\x12\x07\n\x03\x43\x32\x35\x10\x00\x12\x07\n\x03\x43\x35\x30\x10\x01\x12\x08\n\x04\x43\x31\x30\x30\x10\x02\"/\n\x19GeneratePromoCodeResponse\x12\x12\n\npromo_code\x18\x01 \x01(\t\"\x1f\n\x11RemoveUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x14\n\x12RemoveUserResponse\"\x1c\n\x1aGetGlobalPropertiesRequest\"K\n\x1bGetGlobalPropertiesResponse\x12,\n\nassignment\x18\x01 \x03(\x0b\x32\x18.batchx.admin.Assignment\"K\n\nAssignment\x12.\n\x08property\x18\x01 \x01(\x0e\x32\x1c.batchx.admin.GlobalProperty\x12\r\n\x05value\x18\x02 \x01(\t\"H\n\x18SetGlobalPropertyRequest\x12,\n\nassignment\x18\x01 \x01(\x0b\x32\x18.batchx.admin.Assignment\"\x1b\n\x19SetGlobalPropertyResponse\"T\n\x1c\x41\x64\x64\x45nvironmentCreditsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0f\n\x07\x63redits\x18\x02 \x01(\x03\x12\x0e\n\x06reason\x18\x03 \x01(\t\"\x1f\n\x1d\x41\x64\x64\x45nvironmentCreditsResponse\"]\n\x10\x43reateOrgRequest\x12-\n\x08org_data\x18\x01 \x01(\x0b\x32\x1b.batchx.common.Organization\x12\x1a\n\x12\x65nvironment_region\x18\x02 \x01(\t\"\x8b\x02\n\x11\x43reateUserRequest\x12&\n\tuser_data\x18\x01 \x01(\x0b\x32\x13.batchx.common.User\x12\x1a\n\x12\x65nvironment_region\x18\x02 \x01(\t\x12\x42\n\nmembership\x18\x03 \x03(\x0b\x32..batchx.admin.CreateUserRequest.MembershipData\x1an\n\x0eMembershipData\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x43\n\x04type\x18\x02 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipType\"\xbb\x01\n\x17\x43reateMembershipRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x45\n\x04type\x18\x03 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipTypeH\x00\x12\x10\n\x06remove\x18\x04 \x01(\x08H\x00\x42\x1d\n\x1b\x43reateMembershipRequestType\"\x1a\n\x18\x43reateMembershipResponse\"\x14\n\x12\x43reateUserResponse\"\x13\n\x11\x43reateOrgResponse*[\n\x0eGlobalProperty\x12 \n\x1c\x42OOLEAN_DISABLE_RATE_LIMITER\x10\x00\x12\'\n#BOOLEAN_DISABLE_CONCURRENCE_LIMITER\x10\x01\x32\xa5\x06\n\x0c\x41\x64minService\x12T\n\nCreateUser\x12\x1f.batchx.admin.CreateUserRequest\x1a .batchx.admin.CreateUserResponse\"\x03\x90\x02\x02\x12T\n\nRemoveUser\x12\x1f.batchx.admin.RemoveUserRequest\x1a .batchx.admin.RemoveUserResponse\"\x03\x90\x02\x02\x12Q\n\tCreateOrg\x12\x1e.batchx.admin.CreateOrgRequest\x1a\x1f.batchx.admin.CreateOrgResponse\"\x03\x90\x02\x02\x12\x66\n\x10\x43reateMembership\x12%.batchx.admin.CreateMembershipRequest\x1a&.batchx.admin.CreateMembershipResponse\"\x03\x90\x02\x02\x12r\n\x15\x41\x64\x64\x45nvironmentCredits\x12*.batchx.admin.AddEnvironmentCreditsRequest\x1a+.batchx.admin.AddEnvironmentCreditsResponse\"\x00\x12\x66\n\x11SetGlobalProperty\x12&.batchx.admin.SetGlobalPropertyRequest\x1a\'.batchx.admin.SetGlobalPropertyResponse\"\x00\x12l\n\x13GetGlobalProperties\x12(.batchx.admin.GetGlobalPropertiesRequest\x1a).batchx.admin.GetGlobalPropertiesResponse\"\x00\x12\x64\n\x11GeneratePromoCode\x12&.batchx.admin.GeneratePromoCodeRequest\x1a\'.batchx.admin.GeneratePromoCodeResponseB\x1d\n\x0fio.batchx.protoB\nAdminProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\nAdminProto'
  _ADMINSERVICE.methods_by_name['CreateUser']._options = None
  _ADMINSERVICE.methods_by_name['CreateUser']._serialized_options = b'\220\002\002'
  _ADMINSERVICE.methods_by_name['RemoveUser']._options = None
  _ADMINSERVICE.methods_by_name['RemoveUser']._serialized_options = b'\220\002\002'
  _ADMINSERVICE.methods_by_name['CreateOrg']._options = None
  _ADMINSERVICE.methods_by_name['CreateOrg']._serialized_options = b'\220\002\002'
  _ADMINSERVICE.methods_by_name['CreateMembership']._options = None
  _ADMINSERVICE.methods_by_name['CreateMembership']._serialized_options = b'\220\002\002'
  _GLOBALPROPERTY._serialized_start=1378
  _GLOBALPROPERTY._serialized_end=1469
  _GENERATEPROMOCODEREQUEST._serialized_start=44
  _GENERATEPROMOCODEREQUEST._serialized_end=240
  _GENERATEPROMOCODEREQUEST_CREDITS._serialized_start=203
  _GENERATEPROMOCODEREQUEST_CREDITS._serialized_end=240
  _GENERATEPROMOCODERESPONSE._serialized_start=242
  _GENERATEPROMOCODERESPONSE._serialized_end=289
  _REMOVEUSERREQUEST._serialized_start=291
  _REMOVEUSERREQUEST._serialized_end=322
  _REMOVEUSERRESPONSE._serialized_start=324
  _REMOVEUSERRESPONSE._serialized_end=344
  _GETGLOBALPROPERTIESREQUEST._serialized_start=346
  _GETGLOBALPROPERTIESREQUEST._serialized_end=374
  _GETGLOBALPROPERTIESRESPONSE._serialized_start=376
  _GETGLOBALPROPERTIESRESPONSE._serialized_end=451
  _ASSIGNMENT._serialized_start=453
  _ASSIGNMENT._serialized_end=528
  _SETGLOBALPROPERTYREQUEST._serialized_start=530
  _SETGLOBALPROPERTYREQUEST._serialized_end=602
  _SETGLOBALPROPERTYRESPONSE._serialized_start=604
  _SETGLOBALPROPERTYRESPONSE._serialized_end=631
  _ADDENVIRONMENTCREDITSREQUEST._serialized_start=633
  _ADDENVIRONMENTCREDITSREQUEST._serialized_end=717
  _ADDENVIRONMENTCREDITSRESPONSE._serialized_start=719
  _ADDENVIRONMENTCREDITSRESPONSE._serialized_end=750
  _CREATEORGREQUEST._serialized_start=752
  _CREATEORGREQUEST._serialized_end=845
  _CREATEUSERREQUEST._serialized_start=848
  _CREATEUSERREQUEST._serialized_end=1115
  _CREATEUSERREQUEST_MEMBERSHIPDATA._serialized_start=1005
  _CREATEUSERREQUEST_MEMBERSHIPDATA._serialized_end=1115
  _CREATEMEMBERSHIPREQUEST._serialized_start=1118
  _CREATEMEMBERSHIPREQUEST._serialized_end=1305
  _CREATEMEMBERSHIPRESPONSE._serialized_start=1307
  _CREATEMEMBERSHIPRESPONSE._serialized_end=1333
  _CREATEUSERRESPONSE._serialized_start=1335
  _CREATEUSERRESPONSE._serialized_end=1355
  _CREATEORGRESPONSE._serialized_start=1357
  _CREATEORGRESPONSE._serialized_end=1376
  _ADMINSERVICE._serialized_start=1472
  _ADMINSERVICE._serialized_end=2277
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: billing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rbilling.proto\x12\x0e\x62\x61tchx.billing\x1a\x0c\x63ommon.proto\"2\n\x1a\x43reatePaymentIntentRequest\x12\x14\n\x0c\x61mount_cents\x18\x01 \x01(\x05\"4\n\x1b\x43reatePaymentIntentResponse\x12\x15\n\rclient_secret\x18\x01 \x01(\t2\x93\x01\n\x0e\x42illingService\x12s\n\x13\x43reatePaymentIntent\x12*.batchx.billing.CreatePaymentIntentRequest\x1a+.batchx.billing.CreatePaymentIntentResponse\"\x03\x90\x02\x01\x1a\x0c\x82\x97\"\x02\x08\x03\x82\x97\"\x02\x10\x01\x42\x1f\n\x0fio.batchx.protoB\x0c\x42illingProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'billing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\014BillingProto'
  _BILLINGSERVICE._options = None
  _BILLINGSERVICE._serialized_options = b'\202\227\"\002\010\003\202\227\"\002\020\001'
  _BILLINGSERVICE.methods_by_name['CreatePaymentIntent']._options = None
  _BILLINGSERVICE.methods_by_name['CreatePaymentIntent']._serialized_options = b'\220\002\001'
  _CREATEPAYMENTINTENTREQUEST._serialized_start=47
  _CREATEPAYMENTINTENTREQUEST._serialized_end=97
  _CREATEPAYMENTINTENTRESPONSE._serialized_start=99
  _CREATEPAYMENTINTENTRESPONSE._serialized_end=151
  _BILLINGSERVICE._serialized_start=154
  _BILLINGSERVICE._serialized_end=301
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: token.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0btoken.proto\x12\x0c\x62\x61tchx.token\x1a\x0c\x63ommon.proto\"Z\n\x0f\x41\x64\x64TokenRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x15\n\rts_expiration\x18\x04 \x01(\x03\"\x12\n\x10\x41\x64\x64TokenResponse2l\n\x0cTokenService\x12N\n\x08\x41\x64\x64Token\x12\x1d.batchx.token.AddTokenRequest\x1a\x1e.batchx.token.AddTokenResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x02\x42\x1d\n\x0fio.batchx.protoB\nTokenProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'token_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\nTokenProto'
  _TOKENSERVICE._options = None
  _TOKENSERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\002'
  _TOKENSERVICE.methods_by_name['AddToken']._options = None
  _TOKENSERVICE.methods_by_name['AddToken']._serialized_options = b'\220\002\002'
  _ADDTOKENREQUEST._serialized_start=43
  _ADDTOKENREQUEST._serialized_end=133
  _ADDTOKENRESPONSE._serialized_start=135
  _ADDTOKENRESPONSE._serialized_end=153
  _TOKENSERVICE._serialized_start=155
  _TOKENSERVICE._serialized_end=263
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import organization_pb2 as organization__pb2


class OrganizationServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetOrganization = channel.unary_unary(
                '/batchx.organization.OrganizationService/GetOrganization',
                request_serializer=organization__pb2.GetOrganizationRequest.SerializeToString,
                response_deserializer=organization__pb2.GetOrganizationResponse.FromString,
                )
        self.UpdateOrganization = channel.unary_unary(
                '/batchx.organization.OrganizationService/UpdateOrganization',
                request_serializer=organization__pb2.UpdateOrganizationRequest.SerializeToString,
                response_deserializer=organization__pb2.UpdateOrganizationResponse.FromString,
                )
        self.CreateOrganization = channel.unary_unary(
                '/batchx.organization.OrganizationService/CreateOrganization',
                request_serializer=organization__pb2.CreateOrganizationRequest.SerializeToString,
                response_deserializer=organization__pb2.CreateOrganizationResponse.FromString,
                )
        self.InviteMember = channel.unary_unary(
                '/batchx.organization.OrganizationService/InviteMember',
                request_serializer=organization__pb2.InviteMemberRequest.SerializeToString,
                response_deserializer=organization__pb2.InviteMemberResponse.FromString,
                )
        self.HandleInvitation = channel.unary_unary(
                '/batchx.organization.OrganizationService/HandleInvitation',
                request_serializer=organization__pb2.HandleInvitationRequest.SerializeToString,
                response_deserializer=organization__pb2.HandleInvitationResponse.FromString,
                )
        self.ListOrganizationInvitations = channel.unary_unary(
                '/batchx.organization.OrganizationService/ListOrganizationInvitations',
                request_serializer=organization__pb2.ListOrganizationInvitationsRequest.SerializeToString,
                response_deserializer=organization__pb2.ListOrganizationInvitationsResponse.FromString,
                )
        self.ListUserInvitations = channel.unary_unary(
                '/batchx.organization.OrganizationService/ListUserInvitations',
                request_serializer=organization__pb2.ListUserInvitationsRequest.SerializeToString,
                response_deserializer=organization__pb2.ListUserInvitationsResponse.FromString,
                )
        self.DeleteInvitation = channel.unary_unary(
                '/batchx.organization.OrganizationService/DeleteInvitation',
                request_serializer=organization__pb2.DeleteInvitationRequest.SerializeToString,
                response_deserializer=organization__pb2.DeleteInvitationResponse.FromString,
                )
        self.DeleteMembership = channel.unary_unary(
                '/batchx.organization.OrganizationService/DeleteMembership',
                request_serializer=organization__pb2.DeleteMembershipRequest.SerializeToString,
                response_deserializer=organization__pb2.DeleteMembershipResponse.FromString,
                )


class OrganizationServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InviteMember(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HandleInvitation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationInvitations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserInvitations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteInvitation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMembership(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OrganizationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganization,
                    request_deserializer=organization__pb2.GetOrganizationRequest.FromString,
                    response_serializer=organization__pb2.GetOrganizationResponse.SerializeToString,
            ),
            'UpdateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganization,
                    request_deserializer=organization__pb2.UpdateOrganizationRequest.FromString,
                    response_serializer=organization__pb2.UpdateOrganizationResponse.SerializeToString,
            ),
            'CreateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganization,
                    request_deserializer=organization__pb2.CreateOrganizationRequest.FromString,
                    response_serializer=organization__pb2.CreateOrganizationResponse.SerializeToString,
            ),
            'InviteMember': grpc.unary_unary_rpc_method_handler(
                    servicer.InviteMember,
                    request_deserializer=organization__pb2.InviteMemberRequest.FromString,
                    response_serializer=organization__pb2.InviteMemberResponse.SerializeToString,
            ),
            'HandleInvitation': grpc.unary_unary_rpc_method_handler(
                    servicer.HandleInvitation,
                    request_deserializer=organization__pb2.HandleInvitationRequest.FromString,
                    response_serializer=organization__pb2.HandleInvitationResponse.SerializeToString,
            ),
            'ListOrganizationInvitations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationInvitations,
                    request_deserializer=organization__pb2.ListOrganizationInvitationsRequest.FromString,
                    response_serializer=organization__pb2.ListOrganizationInvitationsResponse.SerializeToString,
            ),
            'ListUserInvitations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserInvitations,
                    request_deserializer=organization__pb2.ListUserInvitationsRequest.FromString,
                    response_serializer=organization__pb2.ListUserInvitationsResponse.SerializeToString,
            ),
            'DeleteInvitation': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteInvitation,
                    request_deserializer=organization__pb2.DeleteInvitationRequest.FromString,
                    response_serializer=organization__pb2.DeleteInvitationResponse.SerializeToString,
            ),
            'DeleteMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMembership,
                    request_deserializer=organization__pb2.DeleteMembershipRequest.FromString,
                    response_serializer=organization__pb2.DeleteMembershipResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.organization.OrganizationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OrganizationService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.organization.OrganizationService/GetOrganization',
            organization__pb2.GetOrganizationRequest.SerializeToString,
            organization__pb2.GetOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.organization.OrganizationService/UpdateOrganization',
            organization__pb2.UpdateOrganizationRequest.SerializeToString,
            organization__pb2.UpdateOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.organization.OrganizationService/CreateOrganization',
            organization__pb2.CreateOrganizationRequest.SerializeToString,
            organization__pb2.CreateOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InviteMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.organization.OrganizationService/InviteMember',
            organization__pb2.InviteMemberRequest.SerializeToString,
            organization__pb2.InviteMemberResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HandleInvitation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.organization.OrganizationService/HandleInvitation',
            organization__pb2.HandleInvitationRequest.SerializeToString,
            organization__pb2.HandleInvitationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationInvitations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.organization.OrganizationService/ListOrganizationInvitations',
            organization__pb2.ListOrganizationInvitationsRequest.SerializeToString,
            organization__pb2.ListOrganizationInvitationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserInvitations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.organization.OrganizationService/ListUserInvitations',
            organization__pb2.ListUserInvitationsRequest.SerializeToString,
            organization__pb2.ListUserInvitationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteInvitation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.organization.OrganizationService/DeleteInvitation',
            organization__pb2.DeleteInvitationRequest.SerializeToString,
            organization__pb2.DeleteInvitationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.organization.OrganizationService/DeleteMembership',
            organization__pb2.DeleteMembershipRequest.SerializeToString,
            organization__pb2.DeleteMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: environment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import user_pb2 as user__pb2
from . import organization_pb2 as organization__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x65nvironment.proto\x12\x12\x62\x61tchx.environment\x1a\x0c\x63ommon.proto\x1a\nuser.proto\x1a\x12organization.proto\"\"\n\x14IsIdAvailableRequest\x12\n\n\x02id\x18\x01 \x01(\t\"*\n\x15IsIdAvailableResponse\x12\x11\n\tavailable\x18\x01 \x01(\x08\"\x14\n\x12ListRegionsRequest\")\n\x06Region\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"A\n\x13ListRegionsResponse\x12*\n\x06region\x18\x01 \x03(\x0b\x32\x1a.batchx.environment.Region\",\n\x15GetEnvironmentRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\"\xf8\x04\n\x16GetEnvironmentResponse\x12N\n\rinternal_data\x18\x01 \x01(\x0b\x32\x37.batchx.environment.GetEnvironmentResponse.InternalData\x12\x35\n\ruser_response\x18\x02 \x01(\x0b\x32\x1c.batchx.user.GetUserResponseH\x00\x12M\n\x15organization_response\x18\x03 \x01(\x0b\x32,.batchx.organization.GetOrganizationResponseH\x00\x1a\xff\x02\n\x0cInternalData\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x15\n\rstorage_quota\x18\x02 \x01(\x03\x12\x17\n\x0fstorage_current\x18\x03 \x01(\x03\x12\x19\n\x11\x63omputing_credits\x18\x04 \x01(\x03\x12\x1e\n\x16ts_credits_consumption\x18\x05 \x01(\x03\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x17\n\x0forganization_id\x18\x07 \x01(\t\x12(\n max_credits_consumption_per_hour\x18\x08 \x01(\x03\x12\x1c\n\x14\x63onsumption_per_hour\x18\t \x01(\x03\x12\x18\n\x10max_used_storage\x18\n \x01(\x03\x12\r\n\x05\x66s_v3\x18\x0b \x01(\x08\x12\x12\n\naudit_logs\x18\x0c \x01(\x08\x12\x1f\n\x17\x61rchive_storage_current\x18\r \x01(\x03\x12 \n\x18max_used_archive_storage\x18\x0e \x01(\x03\x42\x06\n\x04Type2\xe0\x02\n\x12\x45nvironmentService\x12l\n\x0eGetEnvironment\x12).batchx.environment.GetEnvironmentRequest\x1a*.batchx.environment.GetEnvironmentResponse\"\x03\x90\x02\x01\x12\x63\n\x0bListRegions\x12&.batchx.environment.ListRegionsRequest\x1a\'.batchx.environment.ListRegionsResponse\"\x03\x90\x02\x01\x12i\n\rIsIdAvailable\x12(.batchx.environment.IsIdAvailableRequest\x1a).batchx.environment.IsIdAvailableResponse\"\x03\x90\x02\x01\x1a\x0c\x82\x97\"\x02\x08\x03\x82\x97\"\x02\x10\x01\x42#\n\x0fio.batchx.protoB\x10\x45nvironmentProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'environment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\020EnvironmentProto'
  _ENVIRONMENTSERVICE._options = None
  _ENVIRONMENTSERVICE._serialized_options = b'\202\227\"\002\010\003\202\227\"\002\020\001'
  _ENVIRONMENTSERVICE.methods_by_name['GetEnvironment']._options = None
  _ENVIRONMENTSERVICE.methods_by_name['GetEnvironment']._serialized_options = b'\220\002\001'
  _ENVIRONMENTSERVICE.methods_by_name['ListRegions']._options = None
  _ENVIRONMENTSERVICE.methods_by_name['ListRegions']._serialized_options = b'\220\002\001'
  _ENVIRONMENTSERVICE.methods_by_name['IsIdAvailable']._options = None
  _ENVIRONMENTSERVICE.methods_by_name['IsIdAvailable']._serialized_options = b'\220\002\001'
  _ISIDAVAILABLEREQUEST._serialized_start=87
  _ISIDAVAILABLEREQUEST._serialized_end=121
  _ISIDAVAILABLERESPONSE._serialized_start=123
  _ISIDAVAILABLERESPONSE._serialized_end=165
  _LISTREGIONSREQUEST._serialized_start=167
  _LISTREGIONSREQUEST._serialized_end=187
  _REGION._serialized_start=189
  _REGION._serialized_end=230
  _LISTREGIONSRESPONSE._serialized_start=232
  _LISTREGIONSRESPONSE._serialized_end=297
  _GETENVIRONMENTREQUEST._serialized_start=299
  _GETENVIRONMENTREQUEST._serialized_end=343
  _GETENVIRONMENTRESPONSE._serialized_start=346
  _GETENVIRONMENTRESPONSE._serialized_end=978
  _GETENVIRONMENTRESPONSE_INTERNALDATA._serialized_start=587
  _GETENVIRONMENTRESPONSE_INTERNALDATA._serialized_end=970
  _ENVIRONMENTSERVICE._serialized_start=981
  _ENVIRONMENTSERVICE._serialized_end=1333
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import image_pb2 as image__pb2
from . import log_pb2 as log__pb2


class ImageServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ImportImage = channel.unary_stream(
                '/batchx.image.ImageService/ImportImage',
                request_serializer=image__pb2.ImportImageRequest.SerializeToString,
                response_deserializer=log__pb2.LogRecord.FromString,
                )
        self.GetPushCredentials = channel.unary_unary(
                '/batchx.image.ImageService/GetPushCredentials',
                request_serializer=image__pb2.GetPushCredentialsRequest.SerializeToString,
                response_deserializer=image__pb2.GetPushCredentialsResponse.FromString,
                )
        self.ListImages = channel.unary_unary(
                '/batchx.image.ImageService/ListImages',
                request_serializer=image__pb2.ListImagesRequest.SerializeToString,
                response_deserializer=image__pb2.ListImagesResponse.FromString,
                )
        self.SearchImages = channel.unary_unary(
                '/batchx.image.ImageService/SearchImages',
                request_serializer=image__pb2.SearchImagesRequest.SerializeToString,
                response_deserializer=image__pb2.SearchImagesResponse.FromString,
                )
        self.GetImage = channel.unary_unary(
                '/batchx.image.ImageService/GetImage',
                request_serializer=image__pb2.GetImageRequest.SerializeToString,
                response_deserializer=image__pb2.GetImageResponse.FromString,
                )
        self.ShareImage = channel.unary_unary(
                '/batchx.image.ImageService/ShareImage',
                request_serializer=image__pb2.ShareImageRequest.SerializeToString,
                response_deserializer=image__pb2.ShareImageResponse.FromString,
                )
        self.CloneImage = channel.unary_unary(
                '/batchx.image.ImageService/CloneImage',
                request_serializer=image__pb2.CloneImageRequest.SerializeToString,
                response_deserializer=image__pb2.CloneImageResponse.FromString,
                )
        self.DeleteImage = channel.unary_stream(
                '/batchx.image.ImageService/DeleteImage',
                request_serializer=image__pb2.DeleteImageRequest.SerializeToString,
                response_deserializer=log__pb2.LogRecord.FromString,
                )
        self.TagImage = channel.unary_unary(
                '/batchx.image.ImageService/TagImage',
                request_serializer=image__pb2.TagImageRequest.SerializeToString,
                response_deserializer=image__pb2.TagImageResponse.FromString,
                )
        self.AreImageExamplesCloned = channel.unary_unary(
                '/batchx.image.ImageService/AreImageExamplesCloned',
                request_serializer=image__pb2.AreImageExamplesClonedRequest.SerializeToString,
                response_deserializer=image__pb2.AreImageExamplesClonedResponse.FromString,
                )
        self.CloneImageExamples = channel.unary_unary(
                '/batchx.image.ImageService/CloneImageExamples',
                request_serializer=image__pb2.CloneImageExamplesRequest.SerializeToString,
                response_deserializer=image__pb2.CloneImageExamplesResponse.FromString,
                )
        self.ListImageExamples = channel.unary_unary(
                '/batchx.image.ImageService/ListImageExamples',
                request_serializer=image__pb2.ListImageExamplesRequest.SerializeToString,
                response_deserializer=image__pb2.ListImageExamplesResponse.FromString,
                )
        self.SetImageExample = channel.unary_unary(
                '/batchx.image.ImageService/SetImageExample',
                request_serializer=image__pb2.SetImageExampleRequest.SerializeToString,
                response_deserializer=image__pb2.SetImageExampleResponse.FromString,
                )
        self.RemoveImageExample = channel.unary_unary(
                '/batchx.image.ImageService/RemoveImageExample',
                request_serializer=image__pb2.RemoveImageExampleRequest.SerializeToString,
                response_deserializer=image__pb2.RemoveImageExampleResponse.FromString,
                )


class ImageServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ImportImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPushCredentials(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListImages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchImages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShareImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloneImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TagImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AreImageExamplesCloned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloneImageExamples(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListImageExamples(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetImageExample(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveImageExample(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ImageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ImportImage': grpc.unary_stream_rpc_method_handler(
                    servicer.ImportImage,
                    request_deserializer=image__pb2.ImportImageRequest.FromString,
                    response_serializer=log__pb2.LogRecord.SerializeToString,
            ),
            'GetPushCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPushCredentials,
                    request_deserializer=image__pb2.GetPushCredentialsRequest.FromString,
                    response_serializer=image__pb2.GetPushCredentialsResponse.SerializeToString,
            ),
            'ListImages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListImages,
                    request_deserializer=image__pb2.ListImagesRequest.FromString,
                    response_serializer=image__pb2.ListImagesResponse.SerializeToString,
            ),
            'SearchImages': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchImages,
                    request_deserializer=image__pb2.SearchImagesRequest.FromString,
                    response_serializer=image__pb2.SearchImagesResponse.SerializeToString,
            ),
            'GetImage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImage,
                    request_deserializer=image__pb2.GetImageRequest.FromString,
                    response_serializer=image__pb2.GetImageResponse.SerializeToString,
            ),
            'ShareImage': grpc.unary_unary_rpc_method_handler(
                    servicer.ShareImage,
                    request_deserializer=image__pb2.ShareImageRequest.FromString,
                    response_serializer=image__pb2.ShareImageResponse.SerializeToString,
            ),
            'CloneImage': grpc.unary_unary_rpc_method_handler(
                    servicer.CloneImage,
                    request_deserializer=image__pb2.CloneImageRequest.FromString,
                    response_serializer=image__pb2.CloneImageResponse.SerializeToString,
            ),
            'DeleteImage': grpc.unary_stream_rpc_method_handler(
                    servicer.DeleteImage,
                    request_deserializer=image__pb2.DeleteImageRequest.FromString,
                    response_serializer=log__pb2.LogRecord.SerializeToString,
            ),
            'TagImage': grpc.unary_unary_rpc_method_handler(
                    servicer.TagImage,
                    request_deserializer=image__pb2.TagImageRequest.FromString,
                    response_serializer=image__pb2.TagImageResponse.SerializeToString,
            ),
            'AreImageExamplesCloned': grpc.unary_unary_rpc_method_handler(
                    servicer.AreImageExamplesCloned,
                    request_deserializer=image__pb2.AreImageExamplesClonedRequest.FromString,
                    response_serializer=image__pb2.AreImageExamplesClonedResponse.SerializeToString,
            ),
            'CloneImageExamples': grpc.unary_unary_rpc_method_handler(
                    servicer.CloneImageExamples,
                    request_deserializer=image__pb2.CloneImageExamplesRequest.FromString,
                    response_serializer=image__pb2.CloneImageExamplesResponse.SerializeToString,
            ),
            'ListImageExamples': grpc.unary_unary_rpc_method_handler(
                    servicer.ListImageExamples,
                    request_deserializer=image__pb2.ListImageExamplesRequest.FromString,
                    response_serializer=image__pb2.ListImageExamplesResponse.SerializeToString,
            ),
            'SetImageExample': grpc.unary_unary_rpc_method_handler(
                    servicer.SetImageExample,
                    request_deserializer=image__pb2.SetImageExampleRequest.FromString,
                    response_serializer=image__pb2.SetImageExampleResponse.SerializeToString,
            ),
            'RemoveImageExample': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveImageExample,
                    request_deserializer=image__pb2.RemoveImageExampleRequest.FromString,
                    response_serializer=image__pb2.RemoveImageExampleResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.image.ImageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ImageService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ImportImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/batchx.image.ImageService/ImportImage',
            image__pb2.ImportImageRequest.SerializeToString,
            log__pb2.LogRecord.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPushCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/GetPushCredentials',
            image__pb2.GetPushCredentialsRequest.SerializeToString,
            image__pb2.GetPushCredentialsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListImages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/ListImages',
            image__pb2.ListImagesRequest.SerializeToString,
            image__pb2.ListImagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchImages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/SearchImages',
            image__pb2.SearchImagesRequest.SerializeToString,
            image__pb2.SearchImagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/GetImage',
            image__pb2.GetImageRequest.SerializeToString,
            image__pb2.GetImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShareImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/ShareImage',
            image__pb2.ShareImageRequest.SerializeToString,
            image__pb2.ShareImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CloneImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/CloneImage',
            image__pb2.CloneImageRequest.SerializeToString,
            image__pb2.CloneImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/batchx.image.ImageService/DeleteImage',
            image__pb2.DeleteImageRequest.SerializeToString,
            log__pb2.LogRecord.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TagImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/TagImage',
            image__pb2.TagImageRequest.SerializeToString,
            image__pb2.TagImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AreImageExamplesCloned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/AreImageExamplesCloned',
            image__pb2.AreImageExamplesClonedRequest.SerializeToString,
            image__pb2.AreImageExamplesClonedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CloneImageExamples(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/CloneImageExamples',
            image__pb2.CloneImageExamplesRequest.SerializeToString,
            image__pb2.CloneImageExamplesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListImageExamples(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/ListImageExamples',
            image__pb2.ListImageExamplesRequest.SerializeToString,
            image__pb2.ListImageExamplesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetImageExample(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/SetImageExample',
            image__pb2.SetImageExampleRequest.SerializeToString,
            image__pb2.SetImageExampleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveImageExample(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.image.ImageService/RemoveImageExample',
            image__pb2.RemoveImageExampleRequest.SerializeToString,
            image__pb2.RemoveImageExampleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x0b\x62\x61tchx.auth\x1a\x0c\x63ommon.proto\"#\n\x12StartSignupRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"\x15\n\x13StartSignupResponse\"\'\n\x13GoogleSigninRequest\x12\x10\n\x08id_token\x18\x01 \x01(\t\"J\n\x14GoogleSigninResponse\x12\x32\n\x0etoken_response\x18\x01 \x01(\x0b\x32\x1a.batchx.auth.TokenResponse\"p\n\x13GoogleSignupRequest\x12\x10\n\x08id_token\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x15\n\rcaptcha_token\x18\x04 \x01(\t\x12\x12\n\npromo_code\x18\x05 \x01(\t\"\x16\n\x14GoogleSignupResponse\"\xa0\x01\n\rSignupRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x12\n\nfirst_name\x18\x04 \x01(\t\x12\x11\n\tlast_name\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x15\n\rcaptcha_token\x18\x07 \x01(\t\x12\x12\n\npromo_code\x18\x08 \x01(\t\"\x10\n\x0eSignupResponse\"?\n\x14\x43onfirmSignupRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x02 \x01(\t\"\x17\n\x15\x43onfirmSignupResponse\"3\n#ResendSignupConfirmationCodeRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"&\n$ResendSignupConfirmationCodeResponse\"?\n\x13RefreshTokenRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\",\n\x14RefreshTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"E\n\x19RevokeRefreshTokenRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"\x1c\n\x1aRevokeRefreshTokenResponse\"\xea\x01\n\x0cLoginRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x12\n\x08password\x18\x02 \x01(\tH\x00\x12I\n\x12\x63hallenge_response\x18\x03 \x01(\x0b\x32+.batchx.auth.LoginRequest.ChallengeResponseH\x00\x1a`\n\x11\x43hallengeResponse\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.batchx.auth.ChallengeType\x12\x0f\n\x07session\x18\x02 \x01(\t\x12\x10\n\x08response\x18\x03 \x01(\tB\x06\n\x04\x63\x61se\"N\n\rTokenResponse\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\x12\x10\n\x08id_token\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\"\xe6\x01\n\rLoginResponse\x12\x34\n\x0etoken_response\x18\x01 \x01(\x0b\x32\x1a.batchx.auth.TokenResponseH\x00\x12H\n\x11\x63hallenge_request\x18\x02 \x01(\x0b\x32+.batchx.auth.LoginResponse.ChallengeRequestH\x00\x1aM\n\x10\x43hallengeRequest\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.batchx.auth.ChallengeType\x12\x0f\n\x07session\x18\x02 \x01(\tB\x06\n\x04\x63\x61se\"*\n\x15\x46orgotPasswordRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\"\x18\n\x16\x46orgotPasswordResponse\"b\n\x1c\x43onfirmForgotPasswordRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x02 \x01(\t\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\"\x1f\n\x1d\x43onfirmForgotPasswordResponse*G\n\nAuthStatus\x12\x0c\n\x08\x43OGINITO\x10\x00\x12\x1f\n\x1b\x43OGINITO_EMAIL_NOT_VERIFIED\x10\x01\x12\n\n\x06GOOGLE\x10\n*N\n\rChallengeType\x12\x15\n\x11UNKNOWN_CHALLENGE\x10\x00\x12\x19\n\x15NEW_PASSWORD_REQUIRED\x10\x01\x12\x0b\n\x07SMS_MFA\x10\x02\x32\xff\x07\n\x0b\x41uthService\x12>\n\x05Login\x12\x19.batchx.auth.LoginRequest\x1a\x1a.batchx.auth.LoginResponse\x12Y\n\x0e\x46orgotPassword\x12\".batchx.auth.ForgotPasswordRequest\x1a#.batchx.auth.ForgotPasswordResponse\x12n\n\x15\x43onfirmForgotPassword\x12).batchx.auth.ConfirmForgotPasswordRequest\x1a*.batchx.auth.ConfirmForgotPasswordResponse\x12S\n\x0cRefreshToken\x12 .batchx.auth.RefreshTokenRequest\x1a!.batchx.auth.RefreshTokenResponse\x12\x65\n\x12RevokeRefreshToken\x12&.batchx.auth.RevokeRefreshTokenRequest\x1a\'.batchx.auth.RevokeRefreshTokenResponse\x12\x41\n\x06Signup\x12\x1a.batchx.auth.SignupRequest\x1a\x1b.batchx.auth.SignupResponse\x12V\n\rConfirmSignup\x12!.batchx.auth.ConfirmSignupRequest\x1a\".batchx.auth.ConfirmSignupResponse\x12S\n\x0cGoogleSignin\x12 .batchx.auth.GoogleSigninRequest\x1a!.batchx.auth.GoogleSigninResponse\x12S\n\x0cGoogleSignup\x12 .batchx.auth.GoogleSignupRequest\x1a!.batchx.auth.GoogleSignupResponse\x12\x83\x01\n\x1cResendSignupConfirmationCode\x12\x30.batchx.auth.ResendSignupConfirmationCodeRequest\x1a\x31.batchx.auth.ResendSignupConfirmationCodeResponse\x12P\n\x0bStartSignup\x12\x1f.batchx.auth.StartSignupRequest\x1a .batchx.auth.StartSignupResponse\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x02\x42\x1c\n\x0fio.batchx.protoB\tAuthProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\tAuthProto'
  _AUTHSERVICE._options = None
  _AUTHSERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\002'
  _AUTHSTATUS._serialized_start=1685
  _AUTHSTATUS._serialized_end=1756
  _CHALLENGETYPE._serialized_start=1758
  _CHALLENGETYPE._serialized_end=1836
  _STARTSIGNUPREQUEST._serialized_start=41
  _STARTSIGNUPREQUEST._serialized_end=76
  _STARTSIGNUPRESPONSE._serialized_start=78
  _STARTSIGNUPRESPONSE._serialized_end=99
  _GOOGLESIGNINREQUEST._serialized_start=101
  _GOOGLESIGNINREQUEST._serialized_end=140
  _GOOGLESIGNINRESPONSE._serialized_start=142
  _GOOGLESIGNINRESPONSE._serialized_end=216
  _GOOGLESIGNUPREQUEST._serialized_start=218
  _GOOGLESIGNUPREQUEST._serialized_end=330
  _GOOGLESIGNUPRESPONSE._serialized_start=332
  _GOOGLESIGNUPRESPONSE._serialized_end=354
  _SIGNUPREQUEST._serialized_start=357
  _SIGNUPREQUEST._serialized_end=517
  _SIGNUPRESPONSE._serialized_start=519
  _SIGNUPRESPONSE._serialized_end=535
  _CONFIRMSIGNUPREQUEST._serialized_start=537
  _CONFIRMSIGNUPREQUEST._serialized_end=600
  _CONFIRMSIGNUPRESPONSE._serialized_start=602
  _CONFIRMSIGNUPRESPONSE._serialized_end=625
  _RESENDSIGNUPCONFIRMATIONCODEREQUEST._serialized_start=627
  _RESENDSIGNUPCONFIRMATIONCODEREQUEST._serialized_end=678
  _RESENDSIGNUPCONFIRMATIONCODERESPONSE._serialized_start=680
  _RESENDSIGNUPCONFIRMATIONCODERESPONSE._serialized_end=718
  _REFRESHTOKENREQUEST._serialized_start=720
  _REFRESHTOKENREQUEST._serialized_end=783
  _REFRESHTOKENRESPONSE._serialized_start=785
  _REFRESHTOKENRESPONSE._serialized_end=829
  _REVOKEREFRESHTOKENREQUEST._serialized_start=831
  _REVOKEREFRESHTOKENREQUEST._serialized_end=900
  _REVOKEREFRESHTOKENRESPONSE._serialized_start=902
  _REVOKEREFRESHTOKENRESPONSE._serialized_end=930
  _LOGINREQUEST._serialized_start=933
  _LOGINREQUEST._serialized_end=1167
  _LOGINREQUEST_CHALLENGERESPONSE._serialized_start=1063
  _LOGINREQUEST_CHALLENGERESPONSE._serialized_end=1159
  _TOKENRESPONSE._serialized_start=1169
  _TOKENRESPONSE._serialized_end=1247
  _LOGINRESPONSE._serialized_start=1250
  _LOGINRESPONSE._serialized_end=1480
  _LOGINRESPONSE_CHALLENGEREQUEST._serialized_start=1395
  _LOGINRESPONSE_CHALLENGEREQUEST._serialized_end=1472
  _FORGOTPASSWORDREQUEST._serialized_start=1482
  _FORGOTPASSWORDREQUEST._serialized_end=1524
  _FORGOTPASSWORDRESPONSE._serialized_start=1526
  _FORGOTPASSWORDRESPONSE._serialized_end=1550
  _CONFIRMFORGOTPASSWORDREQUEST._serialized_start=1552
  _CONFIRMFORGOTPASSWORDREQUEST._serialized_end=1650
  _CONFIRMFORGOTPASSWORDRESPONSE._serialized_start=1652
  _CONFIRMFORGOTPASSWORDRESPONSE._serialized_end=1683
  _AUTHSERVICE._serialized_start=1839
  _AUTHSERVICE._serialized_end=2862
# @@protoc_insertion_point(module_scope)
